﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Articles.Tutorials.Direct2D
{
    public partial class MainWindow : Form
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainWindow"/> class.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Sets the new content to the center of the window.
        /// </summary>
        /// <param name="newChapter">The new chapter.</param>
        private void SetNewContent(Control newChapter)
        {
            //Clear old control
            List<Control> oldControls = new List<Control>();
            foreach (Control actControl in m_contentPanel.Controls) { oldControls.Add(actControl); }
            {
                m_contentPanel.Controls.Clear();
            }
            oldControls.ForEach((x) => x.Dispose());

            //Set new control
            newChapter.Dock = DockStyle.Fill;
            newChapter.BackColor = Color.White;
            m_contentPanel.Controls.Add(newChapter);
        }

        /// <summary>
        /// Called when user wants to close the application.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdCloseClick(object sender, EventArgs e)
        {
            Application.Exit();
        }

        /// <summary>
        /// Called when user wants to see chapter 1.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdChapter1Click(object sender, EventArgs e)
        {
            SetNewContent(new Chapter1());
        }

        /// <summary>
        /// Called when user wants to see chapter 2.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdChapter2Click(object sender, EventArgs e)
        {
            SetNewContent(new Chapter2());
        }

        /// <summary>
        /// Called when user wants to see chapter 3.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdChapter3Click(object sender, EventArgs e)
        {
            SetNewContent(new Chapter3());
        }

        /// <summary>
        /// Called when user wants to see chapter 4.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdChapter4Click(object sender, EventArgs e)
        {
            SetNewContent(new Chapter4());
        }
    }
}
